@@ -28,6 +28,11 @@
 #include <string.h>
 
 // macros
+#if DEBUG >= 1
+#define DEBUGMSG(msg...) errormsg("DEBUG", msg);
+#else 
+#define DEBUGMSG(msg...)
+#endif
 #define myerror(msg...) errormsg(__func__, msg);
 #define stderror() errormsg(__func__, "%s!", strerror(errno));
 
