@@ -41,6 +41,7 @@
 #include "sort.h"
 #include "misc.h"
 #include "platform.h"
+#include "mallocv.h"
 
 #ifdef __WIN32__
 #include <ctype.h>
@@ -48,7 +49,7 @@
 
 // program information
 #define INFO_PROGRAM "FATSort Utility"
-#define INFO_VERSION "0.9.14"
+#define INFO_VERSION "0.9.15"
 #define INFO_AUTHOR "Boris Leidner <fatsort(at)formenos.de>"
 #define INFO_HEADER INFO_PROGRAM " " INFO_VERSION " by " INFO_AUTHOR
 #define INFO_LICENSE	"License GPLv2: GNU GPL version 2 (see LICENSE.txt)\n" \
@@ -62,19 +63,25 @@
 			"\t-f\t Force sorting even if filesystem is mounted\n" \
 			"\t-h\t Print some help\n" \
 			"\t-i\t Print file system information only\n" \
+			"\t-I\t Ignore prefixes \"a\" and \"the\"\n" \
 			"\t-l\t Print current order of files only\n" \
 			"\t-o flag\t Sort order of files where flag is one of\n" \
 			"\t\t\td : directories first (default)\n" \
 			"\t\t\tf : files first\n" \
 			"\t\t\ta : files and directories are not differentiated\n" \
 			"\t-n\t Natural order sorting\n" \
-			"\t-d dir\t Sort directory dir only\n" \
-			"\t-D dir\t Sort directory dir and all subdirectories\n" \
 			"\t-q\t Be quiet\n" \
 			"\t-r\t Sort in reverse order\n" \
 			"\t-R\t Sort in random order\n" \
 			"\t-v\t Print version information\n" \
 			"\n" \
+			"\tThe following options can be specified multiple times:\n" \
+			"\n" \
+			"\t-d dir\t Sort directory dir only\n" \
+			"\t-D dir\t Sort directory dir and all subdirectories\n" \
+			"\t-x dir\t Don't sort directory dir\n" \
+			"\t-X dir\t Don't sort directory dir and its subdirectories\n" \
+			"\n" \
 			"Device must be a FAT16 or FAT32 file system. FAT12 is not supported yet.\n" \
 			"\n" \
 			"Example: fatsort /dev/sda\n" \
@@ -214,7 +221,6 @@ int main(int argc, char *argv[]) {
 	filename=argv[optind];
 #endif
 
-
 	if (OPT_INFO) {
 		infomsg(INFO_HEADER "\n\n");
 		if (printFSInfo(filename) == -1) {
@@ -228,6 +234,11 @@ int main(int argc, char *argv[]) {
 			return -1;
 		}
 	}
+	
+	freeOptions();
+	
+	// report mallocv debugging information
+	REPORT_MEMORY_LEAKS
 
 	return 0;
 }
