@@ -27,12 +27,25 @@
 #include <sys/types.h>
 #include "platform.h"
 #include "FAT_fs.h"
+#include "stringlist.h"
 
-extern u_int32_t OPT_VERSION, OPT_HELP, OPT_INFO, OPT_QUIET, OPT_IGNORE_CASE, OPT_ORDER, OPT_LIST, OPT_REVERSE, OPT_FORCE, OPT_NATURAL_SORT, OPT_RECURSIVE, OPT_RANDOM;
-extern char OPT_DIRECTORY[MAX_PATH_LEN+1];
-
+extern u_int32_t OPT_VERSION, OPT_HELP, OPT_INFO, OPT_QUIET, OPT_IGNORE_CASE,
+		OPT_ORDER, OPT_LIST, OPT_REVERSE, OPT_FORCE, OPT_NATURAL_SORT,
+		OPT_RECURSIVE, OPT_RANDOM;
+extern struct sStringList *OPT_INCL_DIRS, *OPT_EXCL_DIRS, *OPT_INCL_DIRS_REC, *OPT_EXCL_DIRS_REC, *OPT_IGNORE_PREFIXES_LIST;
 
 // parses command line options
 int32_t parse_options(int argc, char *argv[]);
 
+// evaluate whether str matches the include an exclude dir path lists or not
+int32_t matchesDirPathLists(struct sStringList *includes,
+				struct sStringList *includes_recursion,
+				struct sStringList *excludes,
+				struct sStringList *excludes_recursion,
+				char str[MAX_PATH_LEN+1]);
+
+// free options
+void freeOptions();
+
 #endif // __options_h__
+
