@@ -41,6 +41,8 @@
 #include "misc.h"
 #include "fileio.h"
 #include "platform.h"
+#include "stringlist.h"
+#include "mallocv.h"
 
 // used to check if device is mounted
 #if defined(__LINUX__)
@@ -119,12 +121,9 @@ u_int32_t check_mounted(char *filename) {
 	return ret;
 #else	
 	// ok, we don't know how to check this on an unknown platform
-	if (!OPT_FORCE) {
-		myerror("Don't know how to check if filesystem is mounted! Use option '-f' to sort nonetheless.");
-		return -1;
-	} else {
-		return 1;
-	}
+	myerror("Don't know how to check if filesystem is mounted! Use option '-f' to sort nonetheless.");
+
+	return -1;
 #endif
 }
 
@@ -648,35 +647,22 @@ int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, ch
 		return -1;
 	}
 
-	// DEBUG
-/*	struct sClusterChain *ch=&ClusterChain;
-	while(ch != NULL) {
-		printf("%u-", ch->cluster);
-		ch=ch->next;
-	}
-*/
 	if (!OPT_LIST) {
-		// DEBUG
-// 		printf("%s %s\n", OPT_DIRECTORY, path);
 		if (parseClusterChain(fd, bs, ClusterChain, list, &direntries) == -1) {
 			myerror("Failed to parse cluster chain!");
 			return -1;
 		}
-		
-		if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
 
-		if ((strlen(OPT_DIRECTORY) == 0) ||
-		    (strncmp(OPT_DIRECTORY, path, strlen(OPT_DIRECTORY)) == 0)) {
+		// sort matching directories
+		if (matchesDirPathLists(OPT_INCL_DIRS, OPT_INCL_DIRS_REC, OPT_EXCL_DIRS, OPT_EXCL_DIRS_REC, path)) {
+			
+			if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
+			
 			infomsg("Sorting directory %s\n", path);
 			if (writeClusterChain(fd, bs, list, ClusterChain) == -1) {
 				myerror("Failed to write cluster chain!");
 				return -1;
 			}
-			if ((strlen(OPT_DIRECTORY) > 0) &&
-			    !OPT_RECURSIVE) {
-				freeClusterChain(ClusterChain);
-				return 0;
-			}
 		}
 	} else {
 		printf("%s\n", path);
@@ -726,6 +712,8 @@ int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, ch
 		}
 		p=p->next;
 	}
+	
+	freeDirEntryList(list);
 
 	return 0;
 }
@@ -777,10 +765,12 @@ int32_t sort_FAT16_rootdir(FILE *fd, struct sBootSector *bs) {
 	}
 
 	if (!OPT_LIST) {
-		if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
 		
-		if ((strlen(OPT_DIRECTORY) == 0) ||
-		    (strncmp(OPT_DIRECTORY, "/", strlen(OPT_DIRECTORY)) == 0)) {
+		// sort matching directories
+		if (matchesDirPathLists(OPT_INCL_DIRS, OPT_INCL_DIRS_REC, OPT_EXCL_DIRS, OPT_EXCL_DIRS_REC, "/")) {
+			
+			if (OPT_RANDOM) randomizeDirEntryList(list, direntries);
+			
 			infomsg("Sorting directory /\n");
 			fs_seek(fd, BSOffset, SEEK_SET);
 			// write the sorted entries back to the fs
@@ -788,12 +778,8 @@ int32_t sort_FAT16_rootdir(FILE *fd, struct sBootSector *bs) {
 			      myerror("Failed to write FAT entries!");
 			      return -1;
 			}
-			if ((strlen(OPT_DIRECTORY) > 0) &&
-			    !OPT_RECURSIVE) {
-				freeDirEntryList(list);
-				return 0;
-			}
 		}
+		
 	} else {
 		printf("\n");
 	}
